summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 16:12:19 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-27 16:12:19 -0600
commit44c26994c9087200cf941f08df9f77b553a1365e (patch)
treed44f6b84c9218232ee50a929258431c9eadbc99d
parent1334b51442f51913f8d8f1e908674bb20a7ab415 (diff)
downloadtdenetwork-44c26994c9087200cf941f08df9f77b553a1365e.tar.gz
tdenetwork-44c26994c9087200cf941f08df9f77b553a1365e.zip
Rename kioslaves
-rw-r--r--README2
m---------cmake0
-rw-r--r--knewsticker/common/newsiconmgr.cpp12
-rw-r--r--knewsticker/common/newsiconmgr.h2
-rw-r--r--kopete/libkopete/Makefile.am2
-rw-r--r--kopete/plugins/contactnotes/Makefile.am2
-rw-r--r--kopete/protocols/irc/irctransferhandler.cpp6
-rw-r--r--kopete/protocols/irc/irctransferhandler.h2
-rw-r--r--kopete/protocols/jabber/tdeioslave/CMakeLists.txt4
-rw-r--r--kopete/protocols/jabber/tdeioslave/Makefile.am8
-rw-r--r--kopete/protocols/jabber/tdeioslave/jabberdisco.cpp8
-rw-r--r--kopete/protocols/jabber/tdeioslave/jabberdisco.protocol4
-rw-r--r--krdc/TODO2
-rw-r--r--krfb/kcm_krfb/Makefile.am2
-rw-r--r--krfb/krfb/Makefile.am2
-rw-r--r--lanbrowsing/CMakeLists.txt2
-rw-r--r--lanbrowsing/Makefile.am2
-rw-r--r--lanbrowsing/kcmlisa/CMakeLists.txt4
-rw-r--r--lanbrowsing/kcmlisa/Makefile.am4
-rw-r--r--lanbrowsing/kcmlisa/kcmreslisa.cpp8
-rw-r--r--lanbrowsing/kcmlisa/kcmreslisa.h2
-rw-r--r--lanbrowsing/kcmlisa/kcmtdeiolan.cpp (renamed from lanbrowsing/kcmlisa/kcmkiolan.cpp)6
-rw-r--r--lanbrowsing/kcmlisa/kcmtdeiolan.desktop (renamed from lanbrowsing/kcmlisa/kcmkiolan.desktop)0
-rw-r--r--lanbrowsing/kcmlisa/kcmtdeiolan.h (renamed from lanbrowsing/kcmlisa/kcmkiolan.h)6
-rw-r--r--lanbrowsing/kcmlisa/main.cpp8
-rw-r--r--lanbrowsing/kcmlisa/setupwizard.h4
-rw-r--r--lanbrowsing/kio_lan/CMakeLists.txt6
-rw-r--r--lanbrowsing/kio_lan/Makefile.am10
-rw-r--r--lanbrowsing/kio_lan/kio_lan.cpp6
-rw-r--r--lanbrowsing/kio_lan/lan.protocol2
-rw-r--r--lanbrowsing/kio_lan/lisa.desktop2
-rw-r--r--lanbrowsing/kio_lan/rlan.protocol2
-rw-r--r--tdednssd/ioslave/CMakeLists.txt4
-rw-r--r--tdednssd/ioslave/Makefile.am8
-rw-r--r--tdednssd/ioslave/dnssd.cpp2
-rw-r--r--tdednssd/ioslave/invitation.protocol2
-rw-r--r--tdednssd/ioslave/zeroconf.protocol2
37 files changed, 75 insertions, 75 deletions
diff --git a/README b/README
index b5d727c9..c2deb293 100644
--- a/README
+++ b/README
@@ -15,7 +15,7 @@ What it is
* ksirc: IRC client
* ktalkd: talk daemon
* kxmlrpc: TDE XmlRpc Daemon
-* lanbrowsing: lan browsing kio slave
+* lanbrowsing: lan browsing tdeio slave
* krfb: Desktop Sharing server, allow others to access your desktop via VNC
* krdc: a client for Desktop Sharing and other VNC servers
* wifi: Wireless LAN tools
diff --git a/cmake b/cmake
-Subproject 9a217903f9fa35ca12213a6e9ee3d2cb87d1131
+Subproject 274366fb8b90704586d7beef216b765cc0688b0
diff --git a/knewsticker/common/newsiconmgr.cpp b/knewsticker/common/newsiconmgr.cpp
index 200c3375..8864478a 100644
--- a/knewsticker/common/newsiconmgr.cpp
+++ b/knewsticker/common/newsiconmgr.cpp
@@ -96,7 +96,7 @@ void NewsIconMgr::getIcon(const KURL &url)
KIODownload download;
download.url = url;
download.dataOffset = 0;
- m_kioDownload.insert(job, download);
+ m_tdeioDownload.insert(job, download);
}
}
@@ -110,17 +110,17 @@ bool NewsIconMgr::isStdIcon(const TQPixmap &pixmap) const
void NewsIconMgr::slotData(TDEIO::Job *job, const TQByteArray &data)
{
- TQBuffer buf(m_kioDownload[job].data);
+ TQBuffer buf(m_tdeioDownload[job].data);
buf.open(IO_WriteOnly);
- buf.at(m_kioDownload[job].dataOffset);
+ buf.at(m_tdeioDownload[job].dataOffset);
buf.writeBlock(data);
- m_kioDownload[job].dataOffset = buf.at();
+ m_tdeioDownload[job].dataOffset = buf.at();
}
void NewsIconMgr::slotResult(TDEIO::Job *job)
{
- emit gotIcon(m_kioDownload[job].url, TQPixmap(m_kioDownload[job].data));
- m_kioDownload.remove(job);
+ emit gotIcon(m_tdeioDownload[job].url, TQPixmap(m_tdeioDownload[job].data));
+ m_tdeioDownload.remove(job);
}
void NewsIconMgr::slotGotIcon(bool isHost, TQString hostOrURL, TQString iconName)
diff --git a/knewsticker/common/newsiconmgr.h b/knewsticker/common/newsiconmgr.h
index 2cc90cf2..046632c8 100644
--- a/knewsticker/common/newsiconmgr.h
+++ b/knewsticker/common/newsiconmgr.h
@@ -53,7 +53,7 @@ class NewsIconMgr : public TQObject, public DCOPObject
TQString favicon(const KURL &) const;
TQPixmap m_stdIcon;
- KIODownloadMap m_kioDownload;
+ KIODownloadMap m_tdeioDownload;
static NewsIconMgr *m_instance;
};
diff --git a/kopete/libkopete/Makefile.am b/kopete/libkopete/Makefile.am
index 7e90bfc7..53462b8d 100644
--- a/kopete/libkopete/Makefile.am
+++ b/kopete/libkopete/Makefile.am
@@ -5,7 +5,7 @@ endif
include ../../admin/Doxyfile.am
-DOXYGEN_REFERENCES = kio tdecore tdeui
+DOXYGEN_REFERENCES = tdeio tdecore tdeui
DOXYGEN_EXCLUDE = compat
DOXYGEN_SET_PROJECT_NAME = libkopete
diff --git a/kopete/plugins/contactnotes/Makefile.am b/kopete/plugins/contactnotes/Makefile.am
index 3e8705b6..95a1e6b7 100644
--- a/kopete/plugins/contactnotes/Makefile.am
+++ b/kopete/plugins/contactnotes/Makefile.am
@@ -6,7 +6,7 @@ kde_module_LTLIBRARIES = kopete_contactnotes.la
kopete_contactnotes_la_SOURCES = contactnotesplugin.cpp contactnotesedit.cpp
kopete_contactnotes_la_LDFLAGS = -module -no-undefined $(KDE_PLUGIN) $(all_libraries) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
-kopete_contactnotes_la_LIBADD = ../../libkopete/libkopete.la -lkio
+kopete_contactnotes_la_LIBADD = ../../libkopete/libkopete.la -ltdeio
service_DATA = kopete_contactnotes.desktop
servicedir = $(kde_servicesdir)
diff --git a/kopete/protocols/irc/irctransferhandler.cpp b/kopete/protocols/irc/irctransferhandler.cpp
index 5c676e52..fd004985 100644
--- a/kopete/protocols/irc/irctransferhandler.cpp
+++ b/kopete/protocols/irc/irctransferhandler.cpp
@@ -139,18 +139,18 @@ void IRCTransferHandler::connectKopeteTransfer(Kopete::Transfer *kt, KIRC::Trans
// t, TQT_SLOT(slotKopeteTransferDestroyed()));
connect(kt, TQT_SIGNAL(result(TDEIO::Job *)),
- this , TQT_SLOT(kioresult(TDEIO::Job *)));
+ this , TQT_SLOT(tdeioresult(TDEIO::Job *)));
t->initiate();
}
}
-void IRCTransferHandler::kioresult(TDEIO::Job *job)
+void IRCTransferHandler::tdeioresult(TDEIO::Job *job)
{
Kopete::Transfer *kt= (Kopete::Transfer *)job; // FIXME: move to *_cast
if(!kt)
{
- kdDebug(14120) << k_funcinfo << "Kopete::Transfer not found from kio:" << job << endl;
+ kdDebug(14120) << k_funcinfo << "Kopete::Transfer not found from tdeio:" << job << endl;
return;
}
diff --git a/kopete/protocols/irc/irctransferhandler.h b/kopete/protocols/irc/irctransferhandler.h
index 32618120..59d57382 100644
--- a/kopete/protocols/irc/irctransferhandler.h
+++ b/kopete/protocols/irc/irctransferhandler.h
@@ -47,7 +47,7 @@ private slots:
void transferAccepted(Kopete::Transfer *kt, const TQString&file);
void transferRefused(const Kopete::FileTransferInfo &info);
- void kioresult(TDEIO::Job *job);
+ void tdeioresult(TDEIO::Job *job);
private:
IRCTransferHandler();
diff --git a/kopete/protocols/jabber/tdeioslave/CMakeLists.txt b/kopete/protocols/jabber/tdeioslave/CMakeLists.txt
index aaf788bd..4736203b 100644
--- a/kopete/protocols/jabber/tdeioslave/CMakeLists.txt
+++ b/kopete/protocols/jabber/tdeioslave/CMakeLists.txt
@@ -30,9 +30,9 @@ link_directories(
install( FILES jabberdisco.protocol DESTINATION ${SERVICES_INSTALL_DIR} )
-##### kio_jabberdisco (module) ##################
+##### tdeio_jabberdisco (module) ##################
-tde_add_kpart( kio_jabberdisco AUTOMOC
+tde_add_kpart( tdeio_jabberdisco AUTOMOC
SOURCES jabberdisco.cpp
LINK
jabberclient-static
diff --git a/kopete/protocols/jabber/tdeioslave/Makefile.am b/kopete/protocols/jabber/tdeioslave/Makefile.am
index f8b9c651..af69843f 100644
--- a/kopete/protocols/jabber/tdeioslave/Makefile.am
+++ b/kopete/protocols/jabber/tdeioslave/Makefile.am
@@ -10,11 +10,11 @@ INCLUDES = \
-I$(srcdir)/../libiris/cutestuff/network \
$(all_includes)
-kde_module_LTLIBRARIES = kio_jabberdisco.la
+kde_module_LTLIBRARIES = tdeio_jabberdisco.la
-kio_jabberdisco_la_SOURCES = jabberdisco.cpp
-kio_jabberdisco_la_LIBADD = ../libjabberclient.la ../libiris/qca/src/libqca.la ../libiris/iris/include/libiris.la ../libiris/iris/xmpp-im/libiris_xmpp_im.la ../libiris/iris/xmpp-core/libiris_xmpp_core.la ../libiris/iris/jabber/libiris_jabber.la ../libiris/cutestuff/util/libcutestuff_util.la ../libiris/cutestuff/network/libcutestuff_network.la $(LIB_KIO)
-kio_jabberdisco_la_LDFLAGS = -no-undefined -module $(KDE_PLUGIN) $(all_libraries) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+tdeio_jabberdisco_la_SOURCES = jabberdisco.cpp
+tdeio_jabberdisco_la_LIBADD = ../libjabberclient.la ../libiris/qca/src/libqca.la ../libiris/iris/include/libiris.la ../libiris/iris/xmpp-im/libiris_xmpp_im.la ../libiris/iris/xmpp-core/libiris_xmpp_core.la ../libiris/iris/jabber/libiris_jabber.la ../libiris/cutestuff/util/libcutestuff_util.la ../libiris/cutestuff/network/libcutestuff_network.la $(LIB_KIO)
+tdeio_jabberdisco_la_LDFLAGS = -no-undefined -module $(KDE_PLUGIN) $(all_libraries) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
noinst_HEADERS = jabberdisco.h
diff --git a/kopete/protocols/jabber/tdeioslave/jabberdisco.cpp b/kopete/protocols/jabber/tdeioslave/jabberdisco.cpp
index 311cfafd..18cb9319 100644
--- a/kopete/protocols/jabber/tdeioslave/jabberdisco.cpp
+++ b/kopete/protocols/jabber/tdeioslave/jabberdisco.cpp
@@ -1,6 +1,6 @@
/***************************************************************************
- Jabber Service Discovery KIO Slave
+ Jabber Service Discovery TDEIO Slave
-------------------
begin : Wed June 1 2005
copyright : (C) 2005 by Till Gerken <till@tantalo.net>
@@ -33,7 +33,7 @@
#include "jabberclient.h"
JabberDiscoProtocol::JabberDiscoProtocol ( const TQCString &pool_socket, const TQCString &app_socket )
- : TDEIO::SlaveBase ( "kio_jabberdisco", pool_socket, app_socket )
+ : TDEIO::SlaveBase ( "tdeio_jabberdisco", pool_socket, app_socket )
{
kdDebug ( JABBER_DISCO_DEBUG ) << k_funcinfo << "Slave launched." << endl;
@@ -380,13 +380,13 @@ extern "C"
int kdemain ( int argc, char **argv )
{
- TDEApplication app(argc, argv, "kio_jabberdisco", false, true);
+ TDEApplication app(argc, argv, "tdeio_jabberdisco", false, true);
kdDebug(JABBER_DISCO_DEBUG) << k_funcinfo << endl;
if ( argc != 4 )
{
- kdDebug(JABBER_DISCO_DEBUG) << "Usage: kio_jabberdisco protocol domain-socket1 domain-socket2" << endl;
+ kdDebug(JABBER_DISCO_DEBUG) << "Usage: tdeio_jabberdisco protocol domain-socket1 domain-socket2" << endl;
exit(-1);
}
diff --git a/kopete/protocols/jabber/tdeioslave/jabberdisco.protocol b/kopete/protocols/jabber/tdeioslave/jabberdisco.protocol
index fcc0161b..7708d95f 100644
--- a/kopete/protocols/jabber/tdeioslave/jabberdisco.protocol
+++ b/kopete/protocols/jabber/tdeioslave/jabberdisco.protocol
@@ -1,5 +1,5 @@
[Protocol]
-exec=kio_jabberdisco
+exec=tdeio_jabberdisco
protocol=jabber
input=none
output=filesystem
@@ -9,7 +9,7 @@ makedir=false
linking=false
moving=false
Icon=remote
-Description=A KIO slave for Jabber Service Discovery
+Description=A TDEIO slave for Jabber Service Discovery
Description[be]=Модуль tdeioslave для пошуку сервісаў Jabber
Description[bn]=Jabber সার্ভিস ডিসকভারির জন্য একটি কে-আই-ও স্লেভ
Description[bs]=KIO slave za otkrivanje Jabber servisa
diff --git a/krdc/TODO b/krdc/TODO
index be7930a1..4f51f9cd 100644
--- a/krdc/TODO
+++ b/krdc/TODO
@@ -5,7 +5,7 @@ For 3.2:
- SASL authentication
- X11 support
- patch xnest to allow embedding it into a QXEmbed
- - add exec feature to kio_fish or maybe use KSshProcess?
+ - add exec feature to tdeio_fish or maybe use KSshProcess?
Future:
- SSL/TLS?
diff --git a/krfb/kcm_krfb/Makefile.am b/krfb/kcm_krfb/Makefile.am
index a077da21..456d3670 100644
--- a/krfb/kcm_krfb/Makefile.am
+++ b/krfb/kcm_krfb/Makefile.am
@@ -5,7 +5,7 @@ kde_module_LTLIBRARIES = kcm_krfb.la
kcm_krfb_la_SOURCES = configurationwidget.ui kcm_krfb.cpp
kcm_krfb_la_LDFLAGS = $(all_libraries) $(KDE_PLUGIN) -module $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
-kcm_krfb_la_LIBADD = ../krfb/libkrfbconfig.la $(LIB_TDEUI) -lkio
+kcm_krfb_la_LIBADD = ../krfb/libkrfbconfig.la $(LIB_TDEUI) -ltdeio
# Services
xdg_apps_DATA = kcmkrfb.desktop
diff --git a/krfb/krfb/Makefile.am b/krfb/krfb/Makefile.am
index 4546d963..68b163f9 100644
--- a/krfb/krfb/Makefile.am
+++ b/krfb/krfb/Makefile.am
@@ -12,7 +12,7 @@ bin_PROGRAMS = krfb
krfb_SOURCES = rfbcontroller.cc xupdatescanner.cc main.cpp \
connectionwidget.ui krfbifaceimpl.cc krfbiface.skel \
trayicon.cpp connectiondialog.cc
-krfb_LDADD = libkrfbconfig.la ../libvncserver/libvncserver.la ../srvloc/libsrvloc.la -lXtst $(LIB_TDEUI) $(LIBJPEG) -lkio -lDCOP
+krfb_LDADD = libkrfbconfig.la ../libvncserver/libvncserver.la ../srvloc/libsrvloc.la -lXtst $(LIB_TDEUI) $(LIBJPEG) -ltdeio -lDCOP
krfb_LDFLAGS = $(all_libraries) $(KDE_RPATH) $(LIB_QT) -lDCOP $(LIB_TDECORE) -ltdefx
appdatadir = $(kde_datadir)/krfb/pics
diff --git a/lanbrowsing/CMakeLists.txt b/lanbrowsing/CMakeLists.txt
index 146cdefe..8dee0d1e 100644
--- a/lanbrowsing/CMakeLists.txt
+++ b/lanbrowsing/CMakeLists.txt
@@ -11,4 +11,4 @@
add_subdirectory( lisa )
add_subdirectory( kcmlisa )
-add_subdirectory( kio_lan )
+add_subdirectory( tdeio_lan )
diff --git a/lanbrowsing/Makefile.am b/lanbrowsing/Makefile.am
index 4fc6aa8a..326f9322 100644
--- a/lanbrowsing/Makefile.am
+++ b/lanbrowsing/Makefile.am
@@ -1 +1 @@
-SUBDIRS = lisa kcmlisa kio_lan
+SUBDIRS = lisa kcmlisa tdeio_lan
diff --git a/lanbrowsing/kcmlisa/CMakeLists.txt b/lanbrowsing/kcmlisa/CMakeLists.txt
index 12072365..24446a44 100644
--- a/lanbrowsing/kcmlisa/CMakeLists.txt
+++ b/lanbrowsing/kcmlisa/CMakeLists.txt
@@ -24,7 +24,7 @@ link_directories(
##### other data ################################
install( FILES
- kcmkiolan.desktop kcmlisa.desktop kcmreslisa.desktop
+ kcmtdeiolan.desktop kcmlisa.desktop kcmreslisa.desktop
DESTINATION ${APPS_INSTALL_DIR}/.hidden )
@@ -32,7 +32,7 @@ install( FILES
tde_add_kpart( kcm_lanbrowser AUTOMOC
SOURCES
- main.cpp setupwizard.cpp kcmlisa.cpp kcmreslisa.cpp kcmkiolan.cpp
+ main.cpp setupwizard.cpp kcmlisa.cpp kcmreslisa.cpp kcmtdeiolan.cpp
portsettingsbar.cpp findnic.cpp
LINK tdeui-shared
DESTINATION ${PLUGIN_INSTALL_DIR}
diff --git a/lanbrowsing/kcmlisa/Makefile.am b/lanbrowsing/kcmlisa/Makefile.am
index 4d05704b..978d4968 100644
--- a/lanbrowsing/kcmlisa/Makefile.am
+++ b/lanbrowsing/kcmlisa/Makefile.am
@@ -1,6 +1,6 @@
kde_module_LTLIBRARIES = kcm_lanbrowser.la
-kcm_lanbrowser_la_SOURCES = main.cpp setupwizard.cpp kcmlisa.cpp kcmreslisa.cpp kcmkiolan.cpp portsettingsbar.cpp findnic.cpp
+kcm_lanbrowser_la_SOURCES = main.cpp setupwizard.cpp kcmlisa.cpp kcmreslisa.cpp kcmtdeiolan.cpp portsettingsbar.cpp findnic.cpp
kcm_lanbrowser_la_LDFLAGS = $(all_libraries) $(KDE_PLUGIN) -module $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
kcm_lanbrowser_la_LIBADD = -ltdeui
@@ -14,5 +14,5 @@ kcm_lanbrowser_la_METASOURCES = AUTO
messages:
$(XGETTEXT) $(kcm_lanbrowser_la_SOURCES) -o $(podir)/kcmlanbrowser.pot
-apps_DATA = kcmkiolan.desktop kcmlisa.desktop kcmreslisa.desktop
+apps_DATA = kcmtdeiolan.desktop kcmlisa.desktop kcmreslisa.desktop
appsdir = $(kde_appsdir)/.hidden
diff --git a/lanbrowsing/kcmlisa/kcmreslisa.cpp b/lanbrowsing/kcmlisa/kcmreslisa.cpp
index 6b946608..252beadf 100644
--- a/lanbrowsing/kcmlisa/kcmreslisa.cpp
+++ b/lanbrowsing/kcmlisa/kcmreslisa.cpp
@@ -39,7 +39,7 @@
ResLisaSettings::ResLisaSettings(const TQString& config, TQWidget *parent)
: TDECModule(parent)
,m_config(config,false,true)
-,m_kiolanConfig("kio_lanrc",false,true)
+,m_tdeiolanConfig("tdeio_lanrc",false,true)
,m_advancedSettingsButton(0)
,m_suggestSettings(0)
,m_useNmblookup(0)
@@ -168,7 +168,7 @@ void ResLisaSettings::load()
m_pingNames->clear();
m_pingNames->insertStringList(m_config.readListEntry("PingNames",';'));
- m_rlanSidebar->setChecked(m_kiolanConfig.readEntry("sidebarURL", "lan:/") == "rlan:/" ? true : false );
+ m_rlanSidebar->setChecked(m_tdeiolanConfig.readEntry("sidebarURL", "lan:/") == "rlan:/" ? true : false );
}
void ResLisaSettings::save()
@@ -200,8 +200,8 @@ void ResLisaSettings::save()
m_config.sync();
- m_kiolanConfig.writeEntry("sidebarURL", m_rlanSidebar->isChecked() ? "rlan:/" : "lan:/");
- m_kiolanConfig.sync();
+ m_tdeiolanConfig.writeEntry("sidebarURL", m_rlanSidebar->isChecked() ? "rlan:/" : "lan:/");
+ m_tdeiolanConfig.sync();
}
diff --git a/lanbrowsing/kcmlisa/kcmreslisa.h b/lanbrowsing/kcmlisa/kcmreslisa.h
index 69f226db..e395b0ba 100644
--- a/lanbrowsing/kcmlisa/kcmreslisa.h
+++ b/lanbrowsing/kcmlisa/kcmreslisa.h
@@ -47,7 +47,7 @@ class ResLisaSettings:public TDECModule
void suggestSettings();
protected:
TDEConfig m_config;
- TDEConfig m_kiolanConfig;
+ TDEConfig m_tdeiolanConfig;
TQPushButton* m_advancedSettingsButton;
TQPushButton* m_suggestSettings;
TQCheckBox* m_useNmblookup;
diff --git a/lanbrowsing/kcmlisa/kcmkiolan.cpp b/lanbrowsing/kcmlisa/kcmtdeiolan.cpp
index fa3188fc..68e01989 100644
--- a/lanbrowsing/kcmlisa/kcmkiolan.cpp
+++ b/lanbrowsing/kcmlisa/kcmtdeiolan.cpp
@@ -1,5 +1,5 @@
/*
- * kcmkiolan.cpp
+ * kcmtdeiolan.cpp
*
* Copyright (c) 2000 Alexander Neundorf <neundorf@kde.org>
*
@@ -18,7 +18,7 @@
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/
-#include "kcmkiolan.h"
+#include "kcmtdeiolan.h"
#include <tqcheckbox.h>
#include <tqlayout.h>
@@ -99,5 +99,5 @@ void IOSlaveSettings::save()
m_config.sync();
}
-#include "kcmkiolan.moc"
+#include "kcmtdeiolan.moc"
diff --git a/lanbrowsing/kcmlisa/kcmkiolan.desktop b/lanbrowsing/kcmlisa/kcmtdeiolan.desktop
index 78279de8..78279de8 100644
--- a/lanbrowsing/kcmlisa/kcmkiolan.desktop
+++ b/lanbrowsing/kcmlisa/kcmtdeiolan.desktop
diff --git a/lanbrowsing/kcmlisa/kcmkiolan.h b/lanbrowsing/kcmlisa/kcmtdeiolan.h
index 86dd0fa4..fc94e06a 100644
--- a/lanbrowsing/kcmlisa/kcmkiolan.h
+++ b/lanbrowsing/kcmlisa/kcmtdeiolan.h
@@ -1,5 +1,5 @@
/*
- * kcmkiolan.h
+ * kcmtdeiolan.h
*
* Copyright (c) 2000 Alexander Neundorf <neundorf@kde.org>
*
@@ -18,8 +18,8 @@
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
*/
-#ifndef KCMKIOLAN_H
-#define KCMKIOLAN_H
+#ifndef KCMTDEIOLAN_H
+#define KCMTDEIOLAN_H
#include "portsettingsbar.h"
#include <tdecmodule.h>
diff --git a/lanbrowsing/kcmlisa/setupwizard.h b/lanbrowsing/kcmlisa/setupwizard.h
index 87e87064..81b7e45b 100644
--- a/lanbrowsing/kcmlisa/setupwizard.h
+++ b/lanbrowsing/kcmlisa/setupwizard.h
@@ -1,5 +1,5 @@
/*
- * main.cpp for lisa,reslisa,kio_lan and kio_rlan kcm module
+ * main.cpp for lisa,reslisa,tdeio_lan and tdeio_rlan kcm module
*
* Copyright (C) 2000 Alexander Neundorf <neundorf@kde.org>
*
@@ -23,7 +23,7 @@
#include "kcmlisa.h"
#include "kcmreslisa.h"
-#include "kcmkiolan.h"
+#include "kcmtdeiolan.h"
#include "findnic.h"
diff --git a/lanbrowsing/kio_lan/CMakeLists.txt b/lanbrowsing/kio_lan/CMakeLists.txt
index d2fb242f..50794770 100644
--- a/lanbrowsing/kio_lan/CMakeLists.txt
+++ b/lanbrowsing/kio_lan/CMakeLists.txt
@@ -39,10 +39,10 @@ install( FILES
DESTINATION ${DATA_INSTALL_DIR}/konqsidebartng/virtual_folders/services )
-##### kio_lan (module) ##########################
+##### tdeio_lan (module) ##########################
-tde_add_kpart( kio_lan
- SOURCES kio_lan.cpp
+tde_add_kpart( tdeio_lan
+ SOURCES tdeio_lan.cpp
LINK tdeio-shared
DESTINATION ${PLUGIN_INSTALL_DIR}
)
diff --git a/lanbrowsing/kio_lan/Makefile.am b/lanbrowsing/kio_lan/Makefile.am
index 90eaec15..df87f09d 100644
--- a/lanbrowsing/kio_lan/Makefile.am
+++ b/lanbrowsing/kio_lan/Makefile.am
@@ -4,13 +4,13 @@ INCLUDES= $(all_includes)
####### Files
-kde_module_LTLIBRARIES = kio_lan.la
+kde_module_LTLIBRARIES = tdeio_lan.la
-kio_lan_la_SOURCES = kio_lan.cpp
-kio_lan_la_LIBADD = $(LIB_KIO)
-kio_lan_la_LDFLAGS = -module -avoid-version -no-undefined $(all_libraries) $(KDE_RPATH)
+tdeio_lan_la_SOURCES = tdeio_lan.cpp
+tdeio_lan_la_LIBADD = $(LIB_KIO)
+tdeio_lan_la_LDFLAGS = -module -avoid-version -no-undefined $(all_libraries) $(KDE_RPATH)
-noinst_HEADERS = kio_lan.h
+noinst_HEADERS = tdeio_lan.h
kdelnk_DATA = lan.protocol rlan.protocol
kdelnkdir = $(kde_servicesdir)
diff --git a/lanbrowsing/kio_lan/kio_lan.cpp b/lanbrowsing/kio_lan/kio_lan.cpp
index 4e7040ac..e573f7ea 100644
--- a/lanbrowsing/kio_lan/kio_lan.cpp
+++ b/lanbrowsing/kio_lan/kio_lan.cpp
@@ -46,7 +46,7 @@
#include <time.h>
#include <pwd.h>
-#include "kio_lan.h"
+#include "tdeio_lan.h"
#ifndef AF_LOCAL
#define AF_LOCAL AF_UNIX
@@ -66,11 +66,11 @@ extern "C" { KDE_EXPORT int kdemain(int argc, char **argv); }
int kdemain( int argc, char **argv )
{
- TDEInstance instance( "kio_lan" );
+ TDEInstance instance( "tdeio_lan" );
if (argc != 4)
{
- fprintf(stderr, "Usage: kio_lan protocol domain-socket1 domain-socket2\n");
+ fprintf(stderr, "Usage: tdeio_lan protocol domain-socket1 domain-socket2\n");
exit(-1);
}
int isLanIoslave=(strcmp("lan",argv[1])==0);
diff --git a/lanbrowsing/kio_lan/lan.protocol b/lanbrowsing/kio_lan/lan.protocol
index 59c72062..a4101a0e 100644
--- a/lanbrowsing/kio_lan/lan.protocol
+++ b/lanbrowsing/kio_lan/lan.protocol
@@ -1,5 +1,5 @@
[Protocol]
-exec=kio_lan
+exec=tdeio_lan
protocol=lan
input=none
output=filesystem
diff --git a/lanbrowsing/kio_lan/lisa.desktop b/lanbrowsing/kio_lan/lisa.desktop
index 231606b9..b4807d94 100644
--- a/lanbrowsing/kio_lan/lisa.desktop
+++ b/lanbrowsing/kio_lan/lisa.desktop
@@ -63,4 +63,4 @@ Name[zu]=Umbheki zincwadi ze LAN
Open=false
X-TDE-TreeModule=Directory
X-TDE-KonqSidebarModule=konqsidebar_tree
-X-TDE-ConfiguredURL=kio_lanrc:noGroup:sidebarURL
+X-TDE-ConfiguredURL=tdeio_lanrc:noGroup:sidebarURL
diff --git a/lanbrowsing/kio_lan/rlan.protocol b/lanbrowsing/kio_lan/rlan.protocol
index 79fe3c3c..f41507e7 100644
--- a/lanbrowsing/kio_lan/rlan.protocol
+++ b/lanbrowsing/kio_lan/rlan.protocol
@@ -1,5 +1,5 @@
[Protocol]
-exec=kio_lan
+exec=tdeio_lan
protocol=rlan
input=none
output=filesystem
diff --git a/tdednssd/ioslave/CMakeLists.txt b/tdednssd/ioslave/CMakeLists.txt
index 6f15a6b0..fb85beae 100644
--- a/tdednssd/ioslave/CMakeLists.txt
+++ b/tdednssd/ioslave/CMakeLists.txt
@@ -35,9 +35,9 @@ install( FILES
DESTINATION ${DATA_INSTALL_DIR}/remoteview )
-##### kio_zeroconf (module) #####################
+##### tdeio_zeroconf (module) #####################
-tde_add_kpart( kio_zeroconf AUTOMOC
+tde_add_kpart( tdeio_zeroconf AUTOMOC
SOURCES dnssd.cpp
LINK tdednssd-shared tdeio-shared
DESTINATION ${PLUGIN_INSTALL_DIR}
diff --git a/tdednssd/ioslave/Makefile.am b/tdednssd/ioslave/Makefile.am
index 266dfeb4..40de2088 100644
--- a/tdednssd/ioslave/Makefile.am
+++ b/tdednssd/ioslave/Makefile.am
@@ -1,10 +1,10 @@
INCLUDES = $(all_includes)
-kde_module_LTLIBRARIES = kio_zeroconf.la
+kde_module_LTLIBRARIES = tdeio_zeroconf.la
-kio_zeroconf_la_SOURCES = dnssd.cpp
-kio_zeroconf_la_LIBADD = $(LIB_KDNSSD) $(LIB_KIO)
-kio_zeroconf_la_LDFLAGS = -avoid-version -module $(all_libraries) $(KDE_PLUGIN) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
+tdeio_zeroconf_la_SOURCES = dnssd.cpp
+tdeio_zeroconf_la_LIBADD = $(LIB_KDNSSD) $(LIB_KIO)
+tdeio_zeroconf_la_LDFLAGS = -avoid-version -module $(all_libraries) $(KDE_PLUGIN) $(LIB_QT) -lDCOP $(LIB_TDECORE) $(LIB_TDEUI) -ltdefx $(LIB_KIO) -ltdetexteditor
protocol_DATA = zeroconf.protocol invitation.protocol
protocoldir = $(kde_servicesdir)
diff --git a/tdednssd/ioslave/dnssd.cpp b/tdednssd/ioslave/dnssd.cpp
index c045d41c..e33c810c 100644
--- a/tdednssd/ioslave/dnssd.cpp
+++ b/tdednssd/ioslave/dnssd.cpp
@@ -353,7 +353,7 @@ extern "C"
{
// TDEApplication is necessary to use other ioslaves
putenv(strdup("SESSION_MANAGER="));
- TDECmdLineArgs::init(argc, argv, "kio_zeroconf", 0, 0, 0, 0);
+ TDECmdLineArgs::init(argc, argv, "tdeio_zeroconf", 0, 0, 0, 0);
TDECmdLineArgs::addCmdLineOptions( options );
TDEApplication::disableAutoDcopRegistration();
TDEApplication app;
diff --git a/tdednssd/ioslave/invitation.protocol b/tdednssd/ioslave/invitation.protocol
index ef6b068c..1479dcc7 100644
--- a/tdednssd/ioslave/invitation.protocol
+++ b/tdednssd/ioslave/invitation.protocol
@@ -1,5 +1,5 @@
[Protocol]
-exec=kio_zeroconf
+exec=tdeio_zeroconf
protocol=invitation
input=none
diff --git a/tdednssd/ioslave/zeroconf.protocol b/tdednssd/ioslave/zeroconf.protocol
index 2d4a9800..32e76865 100644
--- a/tdednssd/ioslave/zeroconf.protocol
+++ b/tdednssd/ioslave/zeroconf.protocol
@@ -1,5 +1,5 @@
[Protocol]
-exec=kio_zeroconf
+exec=tdeio_zeroconf
protocol=zeroconf
input=none
diff --git a/lanbrowsing/kcmlisa/main.cpp b/lanbrowsing/kcmlisa/main.cpp
index 03d5d045..b7d12c39 100644
--- a/lanbrowsing/kcmlisa/main.cpp
+++ b/lanbrowsing/kcmlisa/main.cpp
@@ -1,5 +1,5 @@
/*
* main.cpp for lisa,reslisa,kio_lan and kio_rlan kcm module
*
* Copyright (C) 2000,2001,2005 Alexander Neundorf <neundorf@kde.org>
*
@@ -29,7 +29,7 @@
#include "kcmlisa.h"
#include "kcmreslisa.h"
-#include "kcmkiolan.h"
+#include "kcmtdeiolan.h"
extern "C"
{
@@ -41,9 +41,9 @@ extern "C"
{
return new ResLisaSettings(TQDir::homeDirPath()+"/.reslisarc", parent);
}
- KDE_EXPORT TDECModule *create_kiolan(TQWidget *parent, const char *)
+ KDE_EXPORT TDECModule *create_tdeiolan(TQWidget *parent, const char *)
{
- return new IOSlaveSettings("kio_lanrc", parent);
+ return new IOSlaveSettings("tdeio_lanrc", parent);
}
}
@@ -1,5 +1,5 @@
/*
- * main.cpp for lisa,reslisa,kio_lan and kio_rlan kcm module
+ * main.cpp for lisa,reslisa,tdeio_lan and tdeio_rlan kcm module
*
* Copyright (C) 2000,2001,2005 Alexander Neundorf <neundorf@kde.org>